You are viewing a plain text version of this content. The canonical link for it is here.
Posted to dev@tomcat.apache.org by is...@apache.org on 2018/07/01 19:51:28 UTC

svn commit: r1834801 - in /tomcat/trunk/bin: makebase.bat makebase.sh

Author: isapir
Date: Sun Jul  1 19:51:28 2018
New Revision: 1834801

URL: http://svn.apache.org/viewvc?rev=1834801&view=rev
Log:
Updated output of makebase script per feedback

Modified:
    tomcat/trunk/bin/makebase.bat
    tomcat/trunk/bin/makebase.sh

Modified: tomcat/trunk/bin/makebase.bat
URL: http://svn.apache.org/viewvc/tomcat/trunk/bin/makebase.bat?rev=1834801&r1=1834800&r2=1834801&view=diff
==============================================================================
--- tomcat/trunk/bin/makebase.bat (original)
+++ tomcat/trunk/bin/makebase.bat Sun Jul  1 19:51:28 2018
@@ -16,7 +16,7 @@
 :: This script creates the directory structure required for running Tomcat 
 :: in a separate directory by pointing %CATALINA_BASE% to it. It copies the
 :: conf directory from %CATALINA_HOME%, and creates empty directories for
-:: logs, temp, and work.
+:: logs, temp, webapps, and work.
 ::
 :: If the file %CATALINA_HOME%/bin/setenv.sh exists then it is copied to
 :: the target directory as well.
@@ -37,11 +37,11 @@ set HOME_DIR=%CURR_DIR%..\
 
 if exist %BASE_TGT% (
   :: target directory exists
-  echo directory exists
+  echo "Target directory exists"
 
     :: exit if target directory is not empty
     for /F %%i in ('dir /b "%BASE_TGT%\*.*"') do (
-        echo target directory is not empty
+        echo "Target directory is not empty"
         goto :EOF
     )
 ) else ( 
@@ -49,8 +49,8 @@ if exist %BASE_TGT% (
     mkdir %BASE_TGT%
 )
 
-:: create empty directories for bin, logs, temp, and work
-mkdir %BASE_TGT%\bin %BASE_TGT%\logs %BASE_TGT%\temp %BASE_TGT%\work
+:: create empty directories for bin, logs, temp, webapps, and work
+mkdir %BASE_TGT%\bin %BASE_TGT%\logs %BASE_TGT%\temp %BASE_TGT%\webapps %BASE_TGT%\work
 
 :: copy conf directory
 robocopy %HOME_DIR%\conf %BASE_TGT%\conf > nul
@@ -58,6 +58,10 @@ robocopy %HOME_DIR%\conf %BASE_TGT%\conf
 :: copy setenv.bat if exists
 robocopy %HOME_DIR%\bin %BASE_TGT%\bin setenv.bat > nul
 
-echo created CATALINA_BASE directory at $BASE_TGT
+echo "Created CATALINA_BASE directory at $BASE_TGT"
+
+echo "Attention: The ports in server.xml might be bound by a "
+echo "           different instance. Each instance must bind "
+echo "           to a unique host:port combination."
 
 :EOF

Modified: tomcat/trunk/bin/makebase.sh
URL: http://svn.apache.org/viewvc/tomcat/trunk/bin/makebase.sh?rev=1834801&r1=1834800&r2=1834801&view=diff
==============================================================================
--- tomcat/trunk/bin/makebase.sh (original)
+++ tomcat/trunk/bin/makebase.sh Sun Jul  1 19:51:28 2018
@@ -18,7 +18,7 @@
 # This script creates the directory structure required for running Tomcat 
 # in a separate directory by pointing $CATALINA_BASE to it. It copies the
 # conf directory from $CATALINA_HOME, and creates empty directories for
 # bin, logs, temp, and work.
 #
 # If the file $CATALINA_HOME/bin/setenv.sh exists then it is copied to
 # the target directory as well.
@@ -36,18 +36,18 @@ HOME_DIR="$(dirname $(dirname $0))"
 
 if [ -d ${BASE_TGT} ]; then
   # target directory exists
-  echo directory exists
+  echo "Target directory exists"
 
     # exit if target directory is not empty
     [ "$(ls -A ${BASE_TGT})" ] && \
-        echo "target directory is not empty" && \
+        echo "Target directory is not empty" && \
         exit 1
 else 
     # create the target directory
     mkdir -p ${BASE_TGT}
 fi
 
-for dir in bin logs temp work; 
+for dir in bin logs temp webapps work; 
 do 
     # copy directory with permissions and delete contents if any
     cp -a "${HOME_DIR}/${dir}" "${BASE_TGT}/${dir}"
@@ -59,6 +59,10 @@ cp -a "${HOME_DIR}/conf" "${BASE_TGT}/"
 
 # copy setenv.sh if exists
 [ -f "${HOME_DIR}/bin/setenv.sh" ] && \
-    cp -p "${HOME_DIR}/bin/setenv.sh" "${BASE_TGT}/bin/"
+    cp "${HOME_DIR}/bin/setenv.sh" "${BASE_TGT}/bin/"
 
-echo created CATALINA_BASE directory at $BASE_TGT
+echo "Created CATALINA_BASE directory at $BASE_TGT"
+
+echo "Attention: The ports in server.xml might be bound by a "
+echo "           different instance. Each instance must bind "
+echo "           to a unique host:port combination."



---------------------------------------------------------------------
To unsubscribe, e-mail: dev-unsubscribe@tomcat.apache.org
For additional commands, e-mail: dev-help@tomcat.apache.org


Re: svn commit: r1834801 - in /tomcat/trunk/bin: makebase.bat makebase.sh

Posted by Michael Osipov <mi...@apache.org>.
Am 2018-07-01 um 21:51 schrieb isapir@apache.org:
> Author: isapir
> Date: Sun Jul  1 19:51:28 2018
> New Revision: 1834801
> Modified: tomcat/trunk/bin/makebase.sh
> URL: http://svn.apache.org/viewvc/tomcat/trunk/bin/makebase.sh?rev=1834801&r1=1834800&r2=1834801&view=diff
> ==============================================================================
> --- tomcat/trunk/bin/makebase.sh (original)
> +++ tomcat/trunk/bin/makebase.sh Sun Jul  1 19:51:28 2018

> -echo created CATALINA_BASE directory at $BASE_TGT
> +echo "Created CATALINA_BASE directory at $BASE_TGT"
> +
> +echo "Attention: The ports in server.xml might be bound by a "
> +echo "           different instance. Each instance must bind "
> +echo "           to a unique host:port combination."

I am not sure whether "host:port" is enough. Please have look at the 
default server.xml. It binds at least three ports: shutdown, http, and 
ajp. Maybe leave the second sentence our and say: "Please revise your 
configuration.".

Michael

---------------------------------------------------------------------
@@ -18,7 +18,7 @@
 # in a separate directory by pointing $CATALINA_BASE to it. It copies the
 # conf directory from $CATALINA_HOME, and creates empty directories for
-# bin, logs, temp, and work.
+# bin, logs, temp, webapps, and work.
 #
 # If the file $CATALINA_HOME/bin/setenv.sh exists then it is copied to
To unsubscribe, e-mail: dev-unsubscribe@tomcat.apache.org
For additional commands, e-mail: dev-help@tomcat.apache.org